==> smartclientcore7.5.6.zip: docs/constants/interfaces/interfaces/CreativeVariation.md <==
[**smartclientcore**](README.md) • **Docs**

***

[smartclientcore](modules.md) / [constants/interfaces](constants/interfaces/README.md) / CreativeVariation

# Interface: CreativeVariation

## Properties

<a id="adparameters" name="adparameters"></a>

### adParameters

> **adParameters**: `null` \| `string`

***

<a id="adslotid" name="adslotid"></a>

### adSlotId

> **adSlotId**: `string`

***

<a id="alttext" name="alttext"></a>

### altText

> **altText**: `null` \| `string`

***

<a id="apiframework" name="apiframework"></a>

### apiFramework

> **apiFramework**: `null` \| `string`

***

<a id="assetheight" name="assetheight"></a>

### assetHeight

> **assetHeight**: `string`

***

<a id="assetwidth" name="assetwidth"></a>

### assetWidth

> **assetWidth**: `string`

***

<a id="clickthroughurl" name="clickthroughurl"></a>

### clickThroughURL

> **clickThroughURL**: `null` \| `string`

***

<a id="clicktracker" name="clicktracker"></a>

### clickTracker

> **clickTracker**: `object`

***

<a id="companionxml" name="companionxml"></a>

### companionXML

> **companionXML**: `Element`

***

<a id="creativeviewtracker" name="creativeviewtracker"></a>

### creativeViewTracker

> **creativeViewTracker**: `object`[]

***

<a id="expandedheight" name="expandedheight"></a>

### expandedHeight

> **expandedHeight**: `string`

***

<a id="expandedwidth" name="expandedwidth"></a>

### expandedWidth

> **expandedWidth**: `string`

***

<a id="hascreative" name="hascreative"></a>

### hasCreative

> **hasCreative**: `boolean`

***

<a id="height" name="height"></a>

### height

> **height**: `null` \| `string`

***

<a id="id" name="id"></a>

### id

> **id**: `string`

***

<a id="isvpaid" name="isvpaid"></a>

### isVPAID

> **isVPAID**: `boolean`

***

<a id="pxratio" name="pxratio"></a>

### pxratio

> **pxratio**: `string`

***

<a id="renderingmode" name="renderingmode"></a>

### renderingMode

> **renderingMode**: `string`

***

<a id="resources" name="resources"></a>

### resources

> **resources**: [`Resource`](constants/interfaces/interfaces/Resource.md)[]

***

<a id="selectedresource" name="selectedresource"></a>

### selectedResource

> **selectedResource**: `null` \| [`Resource`](constants/interfaces/interfaces/Resource.md)

***

<a id="width" name="width"></a>

### width

> **width**: `null` \| `string`

==> smartclientcore7.6.0-dev.zip: docs/constants/interfaces/interfaces/CreativeVariation.md <==
[**smartclientcore**](README.md) • **Docs**

***

[smartclientcore](modules.md) / [constants/interfaces](constants/interfaces/README.md) / CreativeVariation

# Interface: CreativeVariation

## Properties

<a id="adparameters" name="adparameters"></a>

### adParameters

> **adParameters**: `null` \| `string`

***

<a id="adslotid" name="adslotid"></a>

### adSlotId

> **adSlotId**: `string`

***

<a id="alttext" name="alttext"></a>

### altText

> **altText**: `null` \| `string`

***

<a id="apiframework" name="apiframework"></a>

### apiFramework

> **apiFramework**: `null` \| `string`

***

<a id="assetheight" name="assetheight"></a>

### assetHeight

> **assetHeight**: `string`

***

<a id="assetwidth" name="assetwidth"></a>

### assetWidth

> **assetWidth**: `string`

***

<a id="clickthroughurl" name="clickthroughurl"></a>

### clickThroughURL

> **clickThroughURL**: `null` \| `string`

***

<a id="clicktracker" name="clicktracker"></a>

### clickTracker

> **clickTracker**: `object`

***

<a id="companionxml" name="companionxml"></a>

### companionXML

> **companionXML**: `Element`

***

<a id="creativeviewtracker" name="creativeviewtracker"></a>

### creativeViewTracker

> **creativeViewTracker**: [`CreativeViewTracker`](constants/interfaces/interfaces/CreativeViewTracker.md)[]

***

<a id="expandedheight" name="expandedheight"></a>

### expandedHeight

> **expandedHeight**: `string`

***

<a id="expandedwidth" name="expandedwidth"></a>

### expandedWidth

> **expandedWidth**: `string`

***

<a id="hascreative" name="hascreative"></a>

### hasCreative

> **hasCreative**: `boolean`

***

<a id="height" name="height"></a>

### height

> **height**: `null` \| `string`

***

<a id="id" name="id"></a>

### id

> **id**: `string`

***

<a id="isvpaid" name="isvpaid"></a>

### isVPAID

> **isVPAID**: `boolean`

***

<a id="pxratio" name="pxratio"></a>

### pxratio

> **pxratio**: `string`

***

<a id="renderingmode" name="renderingmode"></a>

### renderingMode

> **renderingMode**: `string`

***

<a id="resources" name="resources"></a>

### resources

> **resources**: [`Resource`](constants/interfaces/interfaces/Resource.md)[]

***

<a id="selectedresource" name="selectedresource"></a>

### selectedResource

> **selectedResource**: `null` \| [`Resource`](constants/interfaces/interfaces/Resource.md)

***

<a id="width" name="width"></a>

### width

> **width**: `null` \| `string`
